@@ -18,6 +18,8 @@
 """
 Configuration
 """
+
+
 from QCompute.Define import MeasureFormat
 
 outputInfo = True
@@ -31,6 +33,26 @@ The information also can be found from quantum-hub website.
 Values: True, False
 """
 
+drawCircuitControl = None
+"""
+Draw circuit control.
+
+Draw the circuit to console.
+
+Values: None, [], [...]
+"""
+
+drawCircuitCustomizedGateHashLength = 2
+"""
+Customized gate hash length, when draw circuit.
+
+Hex str, length * 2
+
+|Custom[xxxx]|
+
+Values: int
+"""
+
 measureFormat = MeasureFormat.Bin
 """
 Measure output format setting. 
@@ -54,15 +76,10 @@ Supporting local_baidu_sim2
 Values: True, False
 """
 
-doCompressGate = True
+linuxDirectSim2Cpp = False
+"""
+Use local sim2 cpp directly in linux.
 """
-Compress gate before simulating.
 
-CompressGate can significantly increase the simulator calculating speed. 
-It can combine the neighbour single qubit gate into the nearest two-qubits gate. 
-The process can significant increase the tensor product process.   
 
-Supporting local_baidu_sim2
 
-Values: True, False
-"""
\ No newline at end of file
